@@ -2,7 +2,8 @@ __all__= [
     'table',
     'projects',
     'annotations',
-    'converters'
+    'converters',
+    'metrics'
 ]
 
-__version__ = '0.0.1'
\ No newline at end of file
+__version__ = '0.0.2'
\ No newline at end of file
